@@ -1,5 +1,5 @@
 package Map::Tube::Delhi::Line::Yellow;
-$Map::Tube::Delhi::Line::Yellow::VERSION = '0.39';
+$Map::Tube::Delhi::Line::Yellow::VERSION = '0.40';
 $Map::Tube::Delhi::Line::Yellow::AUTHORITY = 'cpan:MANWAR';
 use 5.006;
 use strict; use warnings;
@@ -10,7 +10,7 @@ Map::Tube::Delhi::Line::Yellow - Delhi Metro Map: Yellow Line.
 
 =head1 VERSION
 
-version 0.39
+version 0.40
 
 =head1 DESCRIPTION
 
@@ -93,7 +93,7 @@ Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 REPOSITORY
 
-L<https://github.com/Manwar/Map-Tube-Delhi>
+L<https://github.com/manwar/Map-Tube-Delhi>
 
 =head1 BUGS
 
